@@ -147,6 +147,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.assets
@@ -163,7 +165,7 @@ class Code(metaclass=jsii.JSIIAbstractClass, jsii_type="cdk-deployer.Code"):
     def __init__(self) -> None:
         jsii.create(self.__class__, self, [])
 
-    @jsii.member(jsii_name="fromAsset") # type: ignore[misc]
+    @jsii.member(jsii_name="fromAsset")
     @builtins.classmethod
     def from_asset(
         cls,
@@ -177,7 +179,7 @@ class Code(metaclass=jsii.JSIIAbstractClass, jsii_type="cdk-deployer.Code"):
         follow_symlinks: typing.Optional[aws_cdk.core.SymlinkFollowMode] = None,
         asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[aws_cdk.core.AssetHashType] = None,
-        bundling: typing.Optional[aws_cdk.core.BundlingOptions] = None,
+        bundling: typing.Optional[typing.Union[aws_cdk.core.BundlingOptions, typing.Dict[str, typing.Any]]] = None,
     ) -> "AssetCode":
         '''Loads the application code from a local disk path.
 
@@ -192,6 +194,9 @@ class Code(metaclass=jsii.JSIIAbstractClass, jsii_type="cdk-deployer.Code"):
         :param asset_hash_type: Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
         :param bundling: Bundle the asset by executing a command in a Docker container or a custom bundling provider. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Code.from_asset)
+            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         options = aws_cdk.aws_s3_assets.AssetOptions(
             readers=readers,
             source_hash=source_hash,
@@ -206,7 +211,7 @@ class Code(metaclass=jsii.JSIIAbstractClass, jsii_type="cdk-deployer.Code"):
 
         return typing.cast("AssetCode", jsii.sinvoke(cls, "fromAsset", [path, options]))
 
-    @jsii.member(jsii_name="fromBucket") # type: ignore[misc]
+    @jsii.member(jsii_name="fromBucket")
     @builtins.classmethod
     def from_bucket(
         cls,
@@ -220,9 +225,14 @@ class Code(metaclass=jsii.JSIIAbstractClass, jsii_type="cdk-deployer.Code"):
         :param key: The object key.
         :param object_version: Optional S3 object version.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Code.from_bucket)
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
+            check_type(argname="argument object_version", value=object_version, expected_type=type_hints["object_version"])
         return typing.cast("S3Code", jsii.sinvoke(cls, "fromBucket", [bucket, key, object_version]))
 
-    @jsii.member(jsii_name="bind") # type: ignore[misc]
+    @jsii.member(jsii_name="bind")
     @abc.abstractmethod
     def bind(self, scope: aws_cdk.core.Construct) -> "CodeConfig":
         '''Called when the deployment object is initialized to allow this object to bind to the stack, add resources and have fun.
@@ -239,6 +249,9 @@ class _CodeProxy(Code):
 
         :param scope: The binding scope. Don't be smart about trying to down-cast or assume it's initialized. You may just use it as a construct scope.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Code.bind)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         return typing.cast("CodeConfig", jsii.invoke(self, "bind", [scope]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the abstract class
@@ -251,13 +264,20 @@ typing.cast(typing.Any, Code).__jsii_proxy_class__ = lambda : _CodeProxy
     name_mapping={"s3_location": "s3Location"},
 )
 class CodeConfig:
-    def __init__(self, *, s3_location: aws_cdk.aws_s3.Location) -> None:
+    def __init__(
+        self,
+        *,
+        s3_location: typing.Union[aws_cdk.aws_s3.Location, typing.Dict[str, typing.Any]],
+    ) -> None:
         '''Result of binding ``Code`` into a ``Ec2Deployer``.
 
         :param s3_location: The location of the code in S3. Default: - code is an s3 location
         '''
         if isinstance(s3_location, dict):
             s3_location = aws_cdk.aws_s3.Location(**s3_location)
+        if __debug__:
+            type_hints = typing.get_type_hints(CodeConfig.__init__)
+            check_type(argname="argument s3_location", value=s3_location, expected_type=type_hints["s3_location"])
         self._values: typing.Dict[str, typing.Any] = {
             "s3_location": s3_location,
         }
@@ -311,6 +331,10 @@ class Ec2Deployer(
         :param instance_roles: The IAM roles associated with the target instances to be deployed to. This is used to ensure the target instances have the appropriate permissions to download the deployment artifact from S3. This prop is only required when the instance roles cannot be dynamically pulled from the supplied deploymentGroup's autoScalingGroups property, for example when deploymentGroup is of type IServerDeploymentGroup or if the deploymentGroup is not associated with an ASG. Default: - gets the instance roles from serverDeploymentGroup.autoScalingGroups[].role
         :param wait_to_complete: Whether the enclosing stack should wait for the deployment to complete. Default: - true
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Ec2Deployer.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = Ec2DeployerProps(
             code=code,
             deployment_group=deployment_group,
@@ -321,37 +345,37 @@ class Ec2Deployer(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="MAX_DEPLOYMENT_TIMEOUT")
     def MAX_DEPLOYMENT_TIMEOUT(cls) -> aws_cdk.core.Duration:
         '''Maximum allowed value for deploymentTimeout prop.'''
         return typing.cast(aws_cdk.core.Duration, jsii.sget(cls, "MAX_DEPLOYMENT_TIMEOUT"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="code")
     def code(self) -> CodeConfig:
         '''The source code to be deployed.'''
         return typing.cast(CodeConfig, jsii.get(self, "code"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="deploymentGroup")
     def deployment_group(self) -> aws_cdk.aws_codedeploy.IServerDeploymentGroup:
         '''The deployment group being deployed to.'''
         return typing.cast(aws_cdk.aws_codedeploy.IServerDeploymentGroup, jsii.get(self, "deploymentGroup"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="waitToComplete")
     def wait_to_complete(self) -> builtins.bool:
         '''Whether the enclosing stack will wait for the deployment to complete.'''
         return typing.cast(builtins.bool, jsii.get(self, "waitToComplete"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="deploymentTimeout")
     def deployment_timeout(self) -> typing.Optional[aws_cdk.core.Duration]:
         '''Amount of time the stack will wait for the deployment operation to complete.'''
         return typing.cast(typing.Optional[aws_cdk.core.Duration], jsii.get(self, "deploymentTimeout"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="instanceRoles")
     def instance_roles(self) -> typing.Optional[typing.List[aws_cdk.aws_iam.IRole]]:
         '''The IAM roles associated with the target instances to be deployed to.
@@ -392,6 +416,13 @@ class Ec2DeployerProps:
         :param instance_roles: The IAM roles associated with the target instances to be deployed to. This is used to ensure the target instances have the appropriate permissions to download the deployment artifact from S3. This prop is only required when the instance roles cannot be dynamically pulled from the supplied deploymentGroup's autoScalingGroups property, for example when deploymentGroup is of type IServerDeploymentGroup or if the deploymentGroup is not associated with an ASG. Default: - gets the instance roles from serverDeploymentGroup.autoScalingGroups[].role
         :param wait_to_complete: Whether the enclosing stack should wait for the deployment to complete. Default: - true
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Ec2DeployerProps.__init__)
+            check_type(argname="argument code", value=code, expected_type=type_hints["code"])
+            check_type(argname="argument deployment_group", value=deployment_group, expected_type=type_hints["deployment_group"])
+            check_type(argname="argument deployment_timeout", value=deployment_timeout, expected_type=type_hints["deployment_timeout"])
+            check_type(argname="argument instance_roles", value=instance_roles, expected_type=type_hints["instance_roles"])
+            check_type(argname="argument wait_to_complete", value=wait_to_complete, expected_type=type_hints["wait_to_complete"])
         self._values: typing.Dict[str, typing.Any] = {
             "code": code,
             "deployment_group": deployment_group,
@@ -476,6 +507,9 @@ class ResourceBindOptions:
         '''
         :param resource_property: The name of the CloudFormation property to annotate with asset metadata. Default: Code
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ResourceBindOptions.__init__)
+            check_type(argname="argument resource_property", value=resource_property, expected_type=type_hints["resource_property"])
         self._values: typing.Dict[str, typing.Any] = {}
         if resource_property is not None:
             self._values["resource_property"] = resource_property
@@ -517,6 +551,11 @@ class S3Code(Code, metaclass=jsii.JSIIMeta, jsii_type="cdk-deployer.S3Code"):
         :param key: -
         :param object_version: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(S3Code.__init__)
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
+            check_type(argname="argument object_version", value=object_version, expected_type=type_hints["object_version"])
         jsii.create(self.__class__, self, [bucket, key, object_version])
 
     @jsii.member(jsii_name="bind")
@@ -525,9 +564,12 @@ class S3Code(Code, metaclass=jsii.JSIIMeta, jsii_type="cdk-deployer.S3Code"):
 
         :param _scope: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(S3Code.bind)
+            check_type(argname="argument _scope", value=_scope, expected_type=type_hints["_scope"])
         return typing.cast(CodeConfig, jsii.invoke(self, "bind", [_scope]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="isInline")
     def is_inline(self) -> builtins.bool:
         return typing.cast(builtins.bool, jsii.get(self, "isInline"))
@@ -548,7 +590,7 @@ class AssetCode(Code, metaclass=jsii.JSIIMeta, jsii_type="cdk-deployer.AssetCode
         follow_symlinks: typing.Optional[aws_cdk.core.SymlinkFollowMode] = None,
         asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[aws_cdk.core.AssetHashType] = None,
-        bundling: typing.Optional[aws_cdk.core.BundlingOptions] = None,
+        bundling: typing.Optional[typing.Union[aws_cdk.core.BundlingOptions, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param path: The path to the asset file or directory.
@@ -562,6 +604,9 @@ class AssetCode(Code, metaclass=jsii.JSIIMeta, jsii_type="cdk-deployer.AssetCode
         :param asset_hash_type: Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
         :param bundling: Bundle the asset by executing a command in a Docker container or a custom bundling provider. The asset path will be mounted at ``/asset-input``. The Docker container is responsible for putting content at ``/asset-output``. The content at ``/asset-output`` will be zipped and used as the final asset. Default: - uploaded as-is to S3 if the asset is a regular file or a .zip file, archived into a .zip file and uploaded to S3 otherwise
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AssetCode.__init__)
+            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         options = aws_cdk.aws_s3_assets.AssetOptions(
             readers=readers,
             source_hash=source_hash,
@@ -582,9 +627,12 @@ class AssetCode(Code, metaclass=jsii.JSIIMeta, jsii_type="cdk-deployer.AssetCode
 
         :param scope: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AssetCode.bind)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         return typing.cast(CodeConfig, jsii.invoke(self, "bind", [scope]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="path")
     def path(self) -> builtins.str:
         '''The path to the asset file or directory.'''
